(*===-- llvm_all_backends.mli - LLVM OCaml Interface ----------*- OCaml -*-===*
 *
 *                     The LLVM Compiler Infrastructure
 *
 * This file is distributed under the University of Illinois Open Source
 * License. See LICENSE.TXT for details.
 *
 *===----------------------------------------------------------------------===*)

(** Initialize all the backends targets *)
val initialize : unit -> unit
